@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0034';
+our $VERSION = '0.0035';
 
 use Moo;
 use strictures 2;
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0034
+version 0.0035
 
 =head1 SYNOPSIS
 
@@ -233,17 +233,20 @@ version 0.0034
 
   my $name = 'Foo!';
 
-  my $id1 = $synth->make_setting(name => $name, group => '...');
-  my $id2 = $synth->make_setting(name => $name, group => '???');
+  my $id1 = $synth->make_setting(name => $name, group => 'foo');
+  my $id2 = $synth->make_setting(name => $name, group => 'bar');
 
   my $setting = $synth->recall_setting(id => $id1);
-  # { group => '...' }
+  # { group => 'foo' }
 
   # update the group key only
-  $synth->make_setting(id => $id1, group => '!!!');
+  $synth->make_setting(id => $id1, group => 'baz');
 
-  my $settings = $synth->search_settings(group => '???');
-  # [ 2 => { group => '???' } ]
+  my $settings = $synth->search_settings(name => $name);
+  # [ 1 => { group => 'baz' }, 2 => { group => 'bar' } ]
+
+  my $settings = $synth->search_settings(group => 'bar');
+  # [ 2 => { group => 'bar' } ]
 
   my $models = $synth->recall_models;
   # [ 'moog_matriarch' ]
